==> GrufSpaces-0.7.1.tgz: GrufSpaces/Extensions/Install.py <==
# -*- coding: utf-8 -*-
## GrufSpaces
## Group environments for elaborating and exchanging information
## Copyright (C)2006 Ingeniweb

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; see the file COPYING. If not, write to the
## Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
"""
$Id: Install.py 27286 2006-08-15 19:44:21Z roeder $
"""
__author__  = 'Maik Roeder'
__docformat__ = 'restructuredtext'

# Python imports
from StringIO import StringIO
import string

# Zope imports
from Products.ExternalMethod.ExternalMethod import ExternalMethod

# CMF imports
from Products.CMFCore.utils import getToolByName
from Products.CMFCore.CMFCorePermissions import ManagePortal

# Archetypes
from Products.Archetypes.Extensions.utils import installTypes, install_subskin
from Products.Archetypes.public import listTypes

# Plone imports
from Products.CMFPlone.migrations.migration_util import addLinesToProperty

# Product import
from Products.GrufSpaces.config import \
    PROJECTNAME, \
    GLOBALS, \
    grufspaces_prefs_configlet

GroupSpace_workflows = (
        ('groupspace_content_intra_workflow', None, 0),
        ('groupspace_content_published_workflow', None, 0),
        ('groupspace_content_shared_workflow', None, 0),
        ('groupspace_content_test_workflow', None, 0),
        ('groupspace_content_submit_workflow', None, 0),
        ('groupspace_folder_intra_workflow', None, 0),
        ('groupspace_folder_published_workflow', None, 0),
        ('groupspace_folder_shared_workflow', None, 0),
        ('groupspace_folder_test_workflow', None, 0),
        ('groupspace_folder_submit_workflow', None, 0),
        ('groupspace_open_close_workflow', ('GroupSpace',), 0),
        ('groupspace_published_workflow', None, 0),
        )

grufspaces_portlets = (
       'here/portlet_groups/macros/portlet',
       'here/portlet_visitor_groups/macros/portlet',
       'here/portlet_groupspaces_changes/macros/portlet',
       'here/portlet_groupspace/macros/portlet',
       )

def install_portlet(self, out):
    """Install portlet in right slots"""
    
    utool = getToolByName(self, 'portal_url')
    portal = utool.getPortalObject()
    portlets = list(portal.getProperty('right_slots'))
    
    for portlet in grufspaces_portlets:
        if portlet not in portlets:
            portlets.append(portlet)
    
    portal._updateProperty('right_slots', portlets)
 
    print >>out, 'GrufSpaces portlet installed.\n'

def uninstall_portlet(self, out):
    """Install portlet in right slots"""
    
    utool = getToolByName(self, 'portal_url')
    portal = utool.getPortalObject()
    portlets = list(portal.getProperty('right_slots'))
    
    for portlet in grufspaces_portlets:
        if portlet in portlets:
            portlets.remove(portlet)
    
    portal._updateProperty('right_slots', portlets)
    
    print >>out, 'GrufSpaces portlet installed.\n'

def install(self):
    """Install GrufSpaces product"""
    out = StringIO()

    # Install types and "switch" external methods
    typeInfo = listTypes(PROJECTNAME)
    installTypes(self, out,
                 typeInfo,
                 PROJECTNAME)
    
    # install catalog indices
    catalog = getToolByName(self, 'portal_catalog')
    if "listGroupSpaceMemberUsers" in catalog.indexes():
        print >>out, "Removing GroupSpace-related index"
        catalog.manage_delIndex('listGroupSpaceMemberUsers')
    if "listGroupSpaceVisitorUsers" in catalog.indexes():
        print >>out, "Removing GroupSpace-related index"
        catalog.manage_delIndex('listGroupSpaceVisitorUsers')

    if not "listGroupSpaceMemberIds" in catalog.indexes():
        print >>out, "Adding GroupSpace-related indexes"
        catalog.manage_addIndex('listGroupSpaceMemberIds', 'KeywordIndex', )
        catalog.manage_reindexIndex('listGroupSpaceMemberIds')
    if not "listGroupSpaceVisitorIds" in catalog.indexes():
        print >>out, "Adding GroupSpace-related indexes"
        catalog.manage_addIndex('listGroupSpaceVisitorIds', 'KeywordIndex', )
        catalog.manage_reindexIndex('listGroupSpaceVisitorIds')
    
    # Install skin
    install_subskin(self, out, GLOBALS)
    
    # Install portlet in right slots
    install_portlet(self, out)
    
    # Install configlet
    cp_tool = getToolByName(self, 'portal_controlpanel')
    cp_tool.registerConfiglet(**grufspaces_prefs_configlet)

    # Custom roles installation
    if not "GroupVisitor" in self.userdefined_roles():
        self._addRole("GroupVisitor")
    if not "GroupMember" in self.userdefined_roles():
        self._addRole("GroupMember")
    if not "GroupAdmin" in self.userdefined_roles():
        self._addRole("GroupAdmin")
    if not "GroupLeader" in self.userdefined_roles():
        self._addRole("GroupLeader")

    # Install Properties
    if not hasattr(self.portal_properties, 'grufspaces_properties'):
        self.portal_properties.addPropertySheet('grufspaces_properties', 'GrufSpaces properties')
    
    props = self.portal_properties.grufspaces_properties

    grufspaces_properties = (
        ('user_search_in_grufspaces', 'boolean', 1),
        ('group_search_in_grufspaces', 'boolean', 0),
        ('use_groupspace_areas', 'boolean', 0),
    )
    for prop_id, prop_type, prop_value in grufspaces_properties:
        if not hasattr(props, prop_id):
            props._setProperty(prop_id, prop_value, prop_type)
    
    gd_tool = getToolByName(self, 'portal_groupdata')
    # Prepare group data tool for delegated group member management
    if not hasattr(gd_tool, 'delegated_group_member_managers'):
        gd_tool._setProperty('delegated_group_member_managers', (), 'lines')
    
    # Install workflows
    wf_tool=getToolByName(self,'portal_workflow')
    for name, types, default in GroupSpace_workflows:
        if name not in wf_tool.objectIds():
            installFunc = ExternalMethod('temp', 'temp', 'GrufSpaces' + '.' + name,
                                         'create' + name.capitalize())
            workflow = installFunc(name)
            wf_tool._setObject(name, workflow)
            if types:
                wf_tool.setChainForPortalTypes(types, name)
            if default:
                wf_tool.setDefaultChain(name)

    # Register GroupSpace as a workspace type                
    g_tool=getToolByName(self,'portal_groups')
    g_tool.setGroupWorkspaceType("GroupSpace")

    # register GroupSpace in use_folder_contents
    props = self.portal_properties.site_properties
    use_folder_tabs = list(props.use_folder_tabs)
    if 'GroupSpace' not in use_folder_tabs:
        use_folder_tabs.append('GroupSpace')
        props.use_folder_tabs=tuple(use_folder_tabs)

    # GroupMembers can see unpublished content in GroupSpace
    pp=getToolByName(self,'portal_properties')
    p = getattr(pp , 'navtree_properties', None)

    if hasattr(p, 'rolesSeeUnpublishedContent'):
        if 'GroupVisitor' not in p.rolesSeeUnpublishedContent:
            addLinesToProperty(p, 'rolesSeeUnpublishedContent', 'GroupVisitor')
        if 'GroupMember' not in p.rolesSeeUnpublishedContent:
            addLinesToProperty(p, 'rolesSeeUnpublishedContent', 'GroupMember')
        if 'GroupAdmin' not in p.rolesSeeUnpublishedContent:
            addLinesToProperty(p, 'rolesSeeUnpublishedContent', 'GroupAdmin')
        if 'GroupLeader' not in p.rolesSeeUnpublishedContent:
            addLinesToProperty(p, 'rolesSeeUnpublishedContent', 'GroupLeader')

    # Install PloneSelenium functional tests
    provider = getToolByName(self, 'portal_selenium', None)
    if provider:
        # Functional Tests
        action = {'id':PROJECTNAME.lower(),
                  'name':PROJECTNAME,
                  'action':'string:here/get_%s_ftests'%PROJECTNAME.lower(),
                  'condition': '',
                  'permission': 'View',
                  'category':'ftests',
                  'visible': 1}
        provider.addAction(**action)
        print >>out, "Action '%s' added to '%s' action provider" % (str(action['id']), 'portal_selenium')
    
    out.write('Installation completed.\n')
    return out.getvalue()

def uninstall(self):
    """Uninstall GrufSpaces product"""
    out = StringIO()
    
    # Uninstall portlet in right slots
    uninstall_portlet(self, out)
    
    # Uninstall configlets
    try:
        cp_tool = getToolByName(self, 'portal_controlpanel')
        cp_tool.unregisterApplication(PROJECTNAME)
    except:
        pass

    # Uninstall workflows
    wf_tool = getToolByName(self, 'portal_workflow', None)
    for workflow_id, types, default in GroupSpace_workflows:
        if workflow_id in wf_tool.objectIds():
            wf_tool._delObject(workflow_id)
        
    out.write('Uninstallation completed.\n')
    return out.getvalue()

try:
    from Products.ATContentTypes.migration.common import migratePortalType
    from Products.ATContentTypes.migration.common import registerMigrator
    from Products.ATContentTypes.migration.atctmigrator import FolderMigrator
    class GroupSpaceMigrator(FolderMigrator):
        src_meta_type = 'GroupSpace'
        src_portal_type = 'OldGroupSpace'
        dst_meta_type = 'ATGroupSpace'
        dst_portal_type = 'GroupSpace'
except:
    pass
    

def migrate(self, **kwargs):
    out = StringIO()
    ttool = getToolByName(self, 'portal_types', None)
    clip = ttool.manage_copyObjects(['GroupSpace'])
    obj=ttool.manage_pasteObjects(clip)
    ttool.manage_renameObject('copy_of_GroupSpace','ATGroupSpace')
    ttool.GroupSpace.manage_changeProperties({'content_meta_type':'GroupSpace'})
    registerMigrator(GroupSpaceMigrator)
    migratePortalType(self, 'GroupSpace', 'ATGroupSpace', out=out,
    migrator=GroupSpaceMigrator, **kwargs)
    ttool.GroupSpace.manage_changeProperties({'content_meta_type':'ATGroupSpace'})
    ttool.manage_delObjects(ids=['ATGroupSpace',])
    out.write('Migration completed.\n')
    return out.getvalue()

==> GrufSpaces-0.7.2.tgz: GrufSpaces/Extensions/Install.py <==
# -*- coding: utf-8 -*-
## GrufSpaces
## Group environments for elaborating and exchanging information
## Copyright (C)2006 Ingeniweb

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; see the file COPYING. If not, write to the
## Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
"""
$Id: Install.py 33836 2006-11-17 15:13:25Z roeder $
"""
__author__  = 'Maik Roeder'
__docformat__ = 'restructuredtext'

# Python imports
from StringIO import StringIO
import string

# Zope imports
from Products.ExternalMethod.ExternalMethod import ExternalMethod

# CMF imports
from Products.CMFCore.utils import getToolByName
from Products.CMFCore.CMFCorePermissions import ManagePortal

# Archetypes
from Products.Archetypes.Extensions.utils import installTypes, install_subskin
from Products.Archetypes.public import listTypes

# Plone imports
from Products.CMFPlone.migrations.migration_util import addLinesToProperty

# Product import
from Products.GrufSpaces.config import \
    PROJECTNAME, \
    GLOBALS, \
    grufspaces_prefs_configlet

GroupSpace_workflows = (
        ('groupspace_content_intra_workflow', None, 0),
        ('groupspace_content_published_workflow', None, 0),
        ('groupspace_content_shared_workflow', None, 0),
        ('groupspace_content_test_workflow', None, 0),
        ('groupspace_content_submit_workflow', None, 0),
        ('groupspace_folder_intra_workflow', None, 0),
        ('groupspace_folder_published_workflow', None, 0),
        ('groupspace_folder_shared_workflow', None, 0),
        ('groupspace_folder_test_workflow', None, 0),
        ('groupspace_folder_submit_workflow', None, 0),
        ('groupspace_open_close_workflow', ('GroupSpace',), 0),
        ('groupspace_published_workflow', None, 0),
        )

grufspaces_portlets = (
       'here/portlet_groups/macros/portlet',
       'here/portlet_visitor_groups/macros/portlet',
       'here/portlet_groupspaces_changes/macros/portlet',
       'here/portlet_groupspace/macros/portlet',
       )

def install_portlet(self, out):
    """Install portlet in right slots"""
    
    utool = getToolByName(self, 'portal_url')
    portal = utool.getPortalObject()
    portlets = list(portal.getProperty('right_slots'))
    
    for portlet in grufspaces_portlets:
        if portlet not in portlets:
            portlets.append(portlet)
    
    portal._updateProperty('right_slots', portlets)
 
    print >>out, 'GrufSpaces portlet installed.\n'

def uninstall_portlet(self, out):
    """Install portlet in right slots"""
    
    utool = getToolByName(self, 'portal_url')
    portal = utool.getPortalObject()
    portlets = list(portal.getProperty('right_slots'))
    
    for portlet in grufspaces_portlets:
        if portlet in portlets:
            portlets.remove(portlet)
    
    portal._updateProperty('right_slots', portlets)
    
    print >>out, 'GrufSpaces portlet installed.\n'

def install(self):
    """Install GrufSpaces product"""
    out = StringIO()

    # Install types and "switch" external methods
    typeInfo = listTypes(PROJECTNAME)
    installTypes(self, out,
                 typeInfo,
                 PROJECTNAME)
    
    # install catalog indices
    catalog = getToolByName(self, 'portal_catalog')
    if "listGroupSpaceMemberUsers" in catalog.indexes():
        print >>out, "Removing GroupSpace-related index"
        catalog.manage_delIndex('listGroupSpaceMemberUsers')
    if "listGroupSpaceVisitorUsers" in catalog.indexes():
        print >>out, "Removing GroupSpace-related index"
        catalog.manage_delIndex('listGroupSpaceVisitorUsers')

    if not "listGroupSpaceMemberIds" in catalog.indexes():
        print >>out, "Adding GroupSpace-related indexes"
        catalog.manage_addIndex('listGroupSpaceMemberIds', 'KeywordIndex', )
        catalog.manage_reindexIndex('listGroupSpaceMemberIds')
    if not "listGroupSpaceVisitorIds" in catalog.indexes():
        print >>out, "Adding GroupSpace-related indexes"
        catalog.manage_addIndex('listGroupSpaceVisitorIds', 'KeywordIndex', )
        catalog.manage_reindexIndex('listGroupSpaceVisitorIds')
    
    # Install skin
    install_subskin(self, out, GLOBALS)
    
    # Install portlet in right slots
    install_portlet(self, out)
    
    # Install configlet
    cp_tool = getToolByName(self, 'portal_controlpanel')
    cp_tool.registerConfiglet(**grufspaces_prefs_configlet)

    # Custom roles installation
    if not "GroupVisitor" in self.userdefined_roles():
        self._addRole("GroupVisitor")
    if not "GroupMember" in self.userdefined_roles():
        self._addRole("GroupMember")
    if not "GroupAdmin" in self.userdefined_roles():
        self._addRole("GroupAdmin")
    if not "GroupLeader" in self.userdefined_roles():
        self._addRole("GroupLeader")

    # Install Properties
    if not hasattr(self.portal_properties, 'grufspaces_properties'):
        self.portal_properties.addPropertySheet('grufspaces_properties', 'GrufSpaces properties')
    
    props = self.portal_properties.grufspaces_properties

    grufspaces_properties = (
        ('user_search_in_grufspaces', 'boolean', 1),
        ('group_search_in_grufspaces', 'boolean', 0),
        ('use_groupspace_areas', 'boolean', 0),
    )
    for prop_id, prop_type, prop_value in grufspaces_properties:
        if not hasattr(props, prop_id):
            props._setProperty(prop_id, prop_value, prop_type)
    
    #gd_tool = getToolByName(self, 'portal_groupdata')
    # Prepare group data tool for delegated group member management
    #if not hasattr(gd_tool, 'delegated_group_member_managers'):
    #    gd_tool._setProperty('delegated_group_member_managers', (), 'lines')
    
    # Install workflows
    wf_tool=getToolByName(self,'portal_workflow')
    for name, types, default in GroupSpace_workflows:
        if name not in wf_tool.objectIds():
            installFunc = ExternalMethod('temp', 'temp', 'GrufSpaces' + '.' + name,
                                         'create' + name.capitalize())
            workflow = installFunc(name)
            wf_tool._setObject(name, workflow)
            if types:
                wf_tool.setChainForPortalTypes(types, name)
            if default:
                wf_tool.setDefaultChain(name)

    # Register GroupSpace as a workspace type                
    g_tool=getToolByName(self,'portal_groups')
    g_tool.setGroupWorkspaceType("GroupSpace")

    # register GroupSpace in use_folder_contents
    props = self.portal_properties.site_properties
    use_folder_tabs = list(props.use_folder_tabs)
    if 'GroupSpace' not in use_folder_tabs:
        use_folder_tabs.append('GroupSpace')
        props.use_folder_tabs=tuple(use_folder_tabs)

    # GroupMembers can see unpublished content in GroupSpace
    pp=getToolByName(self,'portal_properties')
    p = getattr(pp , 'navtree_properties', None)

    if hasattr(p, 'rolesSeeUnpublishedContent'):
        if 'GroupVisitor' not in p.rolesSeeUnpublishedContent:
            addLinesToProperty(p, 'rolesSeeUnpublishedContent', 'GroupVisitor')
        if 'GroupMember' not in p.rolesSeeUnpublishedContent:
            addLinesToProperty(p, 'rolesSeeUnpublishedContent', 'GroupMember')
        if 'GroupAdmin' not in p.rolesSeeUnpublishedContent:
            addLinesToProperty(p, 'rolesSeeUnpublishedContent', 'GroupAdmin')
        if 'GroupLeader' not in p.rolesSeeUnpublishedContent:
            addLinesToProperty(p, 'rolesSeeUnpublishedContent', 'GroupLeader')

    # Install PloneSelenium functional tests
    provider = getToolByName(self, 'portal_selenium', None)
    if provider:
        # Functional Tests
        action = {'id':PROJECTNAME.lower(),
                  'name':PROJECTNAME,
                  'action':'string:here/get_%s_ftests'%PROJECTNAME.lower(),
                  'condition': '',
                  'permission': 'View',
                  'category':'ftests',
                  'visible': 1}
        provider.addAction(**action)
        print >>out, "Action '%s' added to '%s' action provider" % (str(action['id']), 'portal_selenium')
    
    out.write('Installation completed.\n')
    return out.getvalue()

def uninstall(self):
    """Uninstall GrufSpaces product"""
    out = StringIO()
    
    # Uninstall portlet in right slots
    uninstall_portlet(self, out)
    
    # Uninstall configlets
    try:
        cp_tool = getToolByName(self, 'portal_controlpanel')
        cp_tool.unregisterApplication(PROJECTNAME)
    except:
        pass

    # Uninstall workflows
    wf_tool = getToolByName(self, 'portal_workflow', None)
    for workflow_id, types, default in GroupSpace_workflows:
        if workflow_id in wf_tool.objectIds():
            wf_tool._delObject(workflow_id)

    # Uninstall properties
    gd_tool = getToolByName(self, 'portal_groupdata')
    if hasattr(gd_tool, 'delegated_group_member_managers'):
        gd_tool._delProperty('delegated_group_member_managers')
            
    out.write('Uninstallation completed.\n')
    return out.getvalue()

try:
    from Products.ATContentTypes.migration.common import migratePortalType
    from Products.ATContentTypes.migration.common import registerMigrator
    from Products.ATContentTypes.migration.atctmigrator import FolderMigrator
    class GroupSpaceMigrator(FolderMigrator):
        src_meta_type = 'GroupSpace'
        src_portal_type = 'OldGroupSpace'
        dst_meta_type = 'ATGroupSpace'
        dst_portal_type = 'GroupSpace'
except:
    pass
    

def migrate(self, **kwargs):
    out = StringIO()
    ttool = getToolByName(self, 'portal_types', None)
    clip = ttool.manage_copyObjects(['GroupSpace'])
    obj=ttool.manage_pasteObjects(clip)
    ttool.manage_renameObject('copy_of_GroupSpace','ATGroupSpace')
    ttool.GroupSpace.manage_changeProperties({'content_meta_type':'GroupSpace'})
    registerMigrator(GroupSpaceMigrator)
    migratePortalType(self, 'GroupSpace', 'ATGroupSpace', out=out,
    migrator=GroupSpaceMigrator, **kwargs)
    ttool.GroupSpace.manage_changeProperties({'content_meta_type':'ATGroupSpace'})
    ttool.manage_delObjects(ids=['ATGroupSpace',])
    out.write('Migration completed.\n')
    return out.getvalue()
